Module _cargo_task_util

Module _cargo_task_util 

Common cargo_task_util mod will be available to all tasks.

Simply include it in your task module:

  • mod cargo_task_util;
  • use cargo_task_util::*;

Note, the macros ct_info!, ct_warn!, ct_fatal!, and ct_check_fatal! are all defined in this module, and thus are available to task code too. But rust hoists all macros up to the root, so their docs are up there : )

Structs

CTEnv
Cargo-task environment info struct.
CTTaskMeta
Cargo-task task metadata struct.

Enums

CTLogLevel
Log Level enum for CT logging

Functions

ct_env
Fetch the current CTEnv
ct_fatal
Fatal level log function
ct_info
Info level log function
ct_log
Generic CT log function
ct_warn
Warn level log function