[][src]Struct cargo_task::cargo_task_util::CTTaskMeta

pub struct CTTaskMeta {
    pub name: String,
    pub is_script: bool,
    pub min_version: Option<String>,
    pub path: PathBuf,
    pub default: bool,
    pub bootstrap: bool,
    pub help: String,
    pub cargo_deps: Option<String>,
    pub task_deps: Vec<String>,
}

Cargo-task task metadata struct.

Fields

name: String

task name

is_script: bool

true if this task was specified as a single *.ct.rs script file. false if this task was specified as a full crate directory.

min_version: Option<String>

Minimum cargo-task utility version required for this task.

path: PathBuf

task "crate" path

default: bool

does this path run on default cargo task execution?

bootstrap: bool

should this task always run before other tasks? task list will be reloaded after all bootstrap tasks run.

help: String

help info for this task

cargo_deps: Option<String>

any cargo (Cargo.toml) dependencies for a script task

task_deps: Vec<String>

any cargo-task task dependencies