[−][src]Struct cargo_task::cargo_task_util::CTTaskMeta
Cargo-task task metadata struct.
Fields
name: Stringtask name
path: PathBuftask "crate" path
default: booldoes this path run on default cargo task execution?
bootstrap: boolshould this task always run before other tasks? task list will be reloaded after all bootstrap tasks run.
help: Stringhelp info for this task
task_deps: Vec<String>any cargo-task task dependencies